/*****************************************************************
/    This file is part of PC/SC Lite driver for SM1.
/
/    PC/SC Lite driver for SM1 is free software; you can redistribute it and/or
/    modify it under the terms of the GNU General Public License as published by
/    the Free Software Foundation; either version 2 of the License, or
/    (at your option) any later version.
/
/    PC/SC Lite driver for SM1 is distributed in the hope that it will be
/    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
/    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/    GNU General Public License for more details.
/
/    You should have received a copy of the GNU General Public License
/    along with PC/SC Lite driver for SM1; if not, write to the Free Software
/    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
/
/    Copyright Damien Sauveron, 2003
/    contact : damien.sauveron@labri.fr
/
/ File   :   sm.h
/ Author :   Damien Sauveron <damien.sauveron@labri.fr>
/ Date   :   July 8, 2003
/ Purpose:   This provides reader specific low-level calls.
/            See http://www.linuxnet.com for more information.
/ License:   See file COPYING
/
******************************************************************/

#ifndef _SM_H_
#define _SM_H_

#include <pcscdefines.h>
#include <ifdhandler.h>

#include "smartmouse.h"

#include <stdio.h>

#define MAX_SLOT_NB 1

#define RESP_BUF_SIZE (1+256+2)
#define MASK_POWERFLAGS_PUP 0x01
#define MASK_POWERFLAGS_PDWN 0x02

typedef struct SLOT_DESC
{
  DWORD ATRLength;
  UCHAR ATRBuffer[MAX_ATR_SIZE];
  UCHAR PowerFlags;
} SlotDesc;

// Protocols 
enum 
{
  T_0 = 0,
  T_1 = 1
};

#define LunToReaderIndex(Lun) (Lun>>16)
#define LunToSlotIndex(Lun) (Lun & 0x0000FFFF)

// Check if the Lun is not to large for the ReadersSlots table
int iLunCheck(DWORD Lun);

#ifndef TRUE
#define FALSE 0
#define TRUE 1
#endif

RESPONSECODE Open(DWORD Lun, DWORD Channel);
RESPONSECODE Close(DWORD Lun);
RESPONSECODE IsPresent(DWORD Lun);
RESPONSECODE PowerDown(DWORD Lun);
RESPONSECODE PowerUp(DWORD Lun, PUCHAR pcbuffer, PDWORD pwlength);
RESPONSECODE Reset(DWORD Lun, PUCHAR pcbuffer, PDWORD pwlength);
RESPONSECODE SendCommandT0(DWORD Lun,
                           PUCHAR TxBuffer, DWORD TxLength, 
                           PUCHAR RxBuffer, PDWORD RxLength);

#endif /* _SM_H_ */
