/*****************************************************************
/    This file is part of PC/SC Lite driver for SM1.
/
/    PC/SC Lite driver for SM1 is free software; you can redistribute it and/or
/    modify it under the terms of the GNU General Public License as published by
/    the Free Software Foundation; either version 2 of the License, or
/    (at your option) any later version.
/
/    PC/SC Lite driver for SM1 is distributed in the hope that it will be
/    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
/    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/    GNU General Public License for more details.
/
/    You should have received a copy of the GNU General Public License
/    along with PC/SC Lite driver for SM1; if not, write to the Free Software
/    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
/
/    Copyright Damien Sauveron, 2003
/    contact : damien.sauveron@labri.fr
/
/    Based on code from the SCTK project by Alexandre Becoulet.
/    URL: http://freshmeat.net/projects/sctk/
/
/ File   :   smartmouse.h
/ Author :   Damien Sauveron <damien.sauveron@labri.fr>
/ Date   :   July 8, 2003
/ Purpose:   This provides reader specific low-level calls.
/            See http://www.linuxnet.com for more information.
/ License:   See file COPYING
/
******************************************************************/

#ifndef _SMARTMOUSE_H_
# define _SMARTMOUSE_H_

#include <termios.h>


# define PHS_CONV_DIRECT 0
# define PHS_CONV_INDIRECT 1
#define TIME_OUT 200000

/* phoenix/smartmouse specific commands */

enum    phs_command_e
{
  phs_command_direct_mode, /* set direct mode (no byte translation) (def)*/
  phs_command_indir_mode, /* set indirect mode (translate bytes) */
};

/* protocols */

enum    sc_prot_e
{
  sc_prot_phoenix,  /* phoenix smartcard interface */
  sc_prot_smartmouse,  /* smartmouse smartcard interface */
};

/* smart card descriptor struct */

struct    sc_desc_s
{
  enum sc_prot_e  protocol;
  struct termios  ios;
  int    dev_fd;
  unsigned int   timeout_delay;

  const char   *error;

  /* protocol specific mode */
  unsigned int   mode;
};

/* open a smart card device and return the descriptor */

struct sc_desc_s *smartmouse_open(char   *ttysdev);

/* free a smart card descriptor */

void smartmouse_close(struct sc_desc_s *sc);

/* send reset signal to the smart card */

int smartmouse_reset(struct sc_desc_s *sc, unsigned char *pcbuffer, unsigned long *pwlength);

/* send power up signal to the smart card */

int smartmouse_up(struct sc_desc_s *sc, unsigned char *pcbuffer, unsigned long *pwlength);

/* send power down signal to the smart card */

int smartmouse_down(struct sc_desc_s *sc);

/* read bytes from smart card */

int   smartmouse_read(struct sc_desc_s *sc,
                      unsigned char  *data,
                      const unsigned int size);

/* write bytes to smart card */

int smartmouse_write(struct sc_desc_s *sc,
                     const unsigned char  *data,
                     const unsigned int size);

/* return non nul if data are available for reading */

int smartmouse_ispending(struct sc_desc_s *sc);


int smartmouse_ispresent(struct sc_desc_s *sc);

#endif /* _SMARTMOUSE_H_ */
